@@ -1,5 +1,4 @@
-from nostr.key import PublicKey, PrivateKey
-from . import bech32
+from .key import PublicKey, PrivateKey, bech32
 
 
 def from_nip19(nip19string: str):
@@ -13,7 +12,7 @@ def from_nip19(nip19string: str):
         return PublicKey(bytes(data[:-1]))
     elif hrp == 'nsec':
         return PrivateKey(bytes(data[:-1]))
-    elif hrp in ('nevent', 'nprofile'):
+    elif hrp in ('nevent', 'nprofile', 'nrelay'):
         tlv = {0: [], 1: []}
         while data:
             t = data[0]
@@ -26,7 +25,13 @@ def from_nip19(nip19string: str):
             if not v:
                 continue
             tlv[t].append(v)
-        key_or_id = bytes(tlv[0][0]).hex()
+        if tlv[0]:
+            if hrp != 'nrelay':
+                key_or_id = bytes(tlv[0][0]).hex()
+            else:
+                key_or_id = bytes(tlv[0][0]).decode()
+        else:
+            key_or_id = ''
         relays = []
         for relay in tlv[1]:
             relays.append(bytes(relay).decode('utf8'))
@@ -39,18 +44,27 @@ def to_nip19(ntype: str, payload: str, relays=None):
     """
     if ntype in ('npub', 'nsec'):
         data = bytes.fromhex(payload)
-    elif ntype in ('nprofile', 'nevent'):
-        # payload is event id
-        event_id = bytes.fromhex(payload)
+    elif ntype in ('nprofile', 'nevent', 'nrelay'):
         data = bytearray()
-        data.append(0)
-        data.append(len(event_id))
-        data.extend(event_id)
-        if relays:
-            for r in relays:
-                r = r.encode()
-                data.append(1)
-                data.append(len(r))
-                data.extend(r)
+        if ntype == 'nrelay':
+            # payload is the relay url
+            encoded = payload.encode()
+            data.append(0)
+            data.append(len(encoded))
+            data.extend(encoded)
+        else:
+            # payload is event id
+            event_id = bytes.fromhex(payload)
+            data.append(0)
+            data.append(len(event_id))
+            data.extend(event_id)
+            if relays:
+                for r in relays:
+                    r = r.encode()
+                    data.append(1)
+                    data.append(len(r))
+                    data.extend(r)
+    else:
+        data = payload.encode()
     converted_bits = bech32.convertbits(data, 8, 5)
     return bech32.bech32_encode(ntype, converted_bits, bech32.Encoding.BECH32)
